# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.simple_price import SimplePrice
from coingeckopublicapiv3.models.simple_token_price import SimpleTokenPrice


class SimpleController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(SimpleController, self).__init__(config)

    def simple_price(self,
                     vs_currencies,
                     ids=None,
                     names=None,
                     symbols=None,
                     include_tokens=None,
                     include_market_cap=None,
                     include_24_hr_vol=None,
                     include_24_hr_change=None,
                     include_last_updated_at=None,
                     precision=None):
        """Does a GET request to /simple/price.

        This endpoint allows you to **query the prices of one or more coins by
        using their unique Coin API IDs**

        Args:
            vs_currencies (str): target currency of coins, comma-separated if
                querying more than 1 currency. <br> *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            ids (str, optional): coins' IDs, comma-separated if querying more
                than 1 coin. <br> *refers to
                [`/coins/list`](/reference/coins-list).
            names (str, optional): coins' names, comma-separated if querying
                more than 1 coin.
            symbols (str, optional): coins' symbols, comma-separated if
                querying more than 1 coin.
            include_tokens (IncludeTokensEnum, optional): for `symbols`
                lookups, specify `all` to include all matching tokens <br>
                Default `top` returns top-ranked tokens (by market cap or
                volume)
            include_market_cap (bool, optional): include market
                capitalization, default: false
            include_24_hr_vol (bool, optional): include 24hr volume, default:
                false
            include_24_hr_change (bool, optional): include 24hr change,
                default: false
            include_last_updated_at (bool, optional): include last updated
                price time in UNIX, default: false
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            SimplePrice: Response from the API. price(s) of cryptocurrency

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/simple/price')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('vs_currencies')
                         .value(vs_currencies))
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .query_param(Parameter()
                         .key('names')
                         .value(names))
            .query_param(Parameter()
                         .key('symbols')
                         .value(symbols))
            .query_param(Parameter()
                         .key('include_tokens')
                         .value(include_tokens))
            .query_param(Parameter()
                         .key('include_market_cap')
                         .value(include_market_cap))
            .query_param(Parameter()
                         .key('include_24hr_vol')
                         .value(include_24_hr_vol))
            .query_param(Parameter()
                         .key('include_24hr_change')
                         .value(include_24_hr_change))
            .query_param(Parameter()
                         .key('include_last_updated_at')
                         .value(include_last_updated_at))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(SimplePrice.from_dictionary)
        ).execute()

    def simple_token_price(self,
                           id,
                           contract_addresses,
                           vs_currencies,
                           include_market_cap=None,
                           include_24_hr_vol=None,
                           include_24_hr_change=None,
                           include_last_updated_at=None,
                           precision=None):
        """Does a GET request to /simple/token_price/{id}.

        This endpoint allows you to **query one or more token prices using
        their token contract addresses**

        Args:
            id (str): asset platform's ID <br> *refers to
                [`/asset_platforms`](/reference/asset-platforms-list).
            contract_addresses (str): the contract address of a token
            vs_currencies (str): target currency of coins, comma-separated if
                querying more than 1 currency. <br> *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            include_market_cap (bool, optional): include market
                capitalization, default: false
            include_24_hr_vol (bool, optional): include 24hr volume, default:
                false
            include_24_hr_change (bool, optional): include 24hr change <br>
                default: false
            include_last_updated_at (bool, optional): include last updated
                price time in UNIX , default: false
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            SimpleTokenPrice: Response from the API. price(s) of cryptocurrency

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/simple/token_price/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('contract_addresses')
                         .value(contract_addresses))
            .query_param(Parameter()
                         .key('vs_currencies')
                         .value(vs_currencies))
            .query_param(Parameter()
                         .key('include_market_cap')
                         .value(include_market_cap))
            .query_param(Parameter()
                         .key('include_24hr_vol')
                         .value(include_24_hr_vol))
            .query_param(Parameter()
                         .key('include_24hr_change')
                         .value(include_24_hr_change))
            .query_param(Parameter()
                         .key('include_last_updated_at')
                         .value(include_last_updated_at))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(SimpleTokenPrice.from_dictionary)
        ).execute()

    def simple_supported_currencies(self):
        """Does a GET request to /simple/supported_vs_currencies.

        This endpoint allows you to **query all the supported currencies on
        CoinGecko**

        Returns:
            List[str]: Response from the API. list of supported currencies

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/simple/supported_vs_currencies')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Categories1(object):

    """Implementation of the 'Categories1' model.

    Attributes:
        id (str): category ID
        name (str): category name

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name'
    }

    _optionals = [
        'id',
        'name',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP):
        """Constructor for the Categories1 class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class CoinsMarketChartRange(object):

    """Implementation of the 'CoinsMarketChartRange' model.

    Attributes:
        prices (List[float]): The model property of type List[float].
        market_caps (List[float]): The model property of type List[float].
        total_volumes (List[float]): The model property of type List[float].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "prices": 'prices',
        "market_caps": 'market_caps',
        "total_volumes": 'total_volumes'
    }

    _optionals = [
        'prices',
        'market_caps',
        'total_volumes',
    ]

    def __init__(self,
                 prices=APIHelper.SKIP,
                 market_caps=APIHelper.SKIP,
                 total_volumes=APIHelper.SKIP):
        """Constructor for the CoinsMarketChartRange class"""

        # Initialize members of the class
        if prices is not APIHelper.SKIP:
            self.prices = prices 
        if market_caps is not APIHelper.SKIP:
            self.market_caps = market_caps 
        if total_volumes is not APIHelper.SKIP:
            self.total_volumes = total_volumes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        prices = dictionary.get("prices") if dictionary.get("prices") else APIHelper.SKIP
        market_caps = dictionary.get("market_caps") if dictionary.get("market_caps") else APIHelper.SKIP
        total_volumes = dictionary.get("total_volumes") if dictionary.get("total_volumes") else APIHelper.SKIP
        # Return an object of this model
        return cls(prices,
                   market_caps,
                   total_volumes)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'prices={(self.prices if hasattr(self, "prices") else None)!r}, '
                f'market_caps={(self.market_caps if hasattr(self, "market_caps") else None)!r}, '
                f'total_volumes={(self.total_volumes if hasattr(self, "total_volumes") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'prices={(self.prices if hasattr(self, "prices") else None)!s}, '
                f'market_caps={(self.market_caps if hasattr(self, "market_caps") else None)!s}, '
                f'total_volumes={(self.total_volumes if hasattr(self, "total_volumes") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order4Enum(object):

    """Implementation of the 'order4' enum.

    Attributes:
        NAME_ASC: The enum member of type str.
        NAME_DESC: The enum member of type str.
        OPEN_INTEREST_BTC_ASC: The enum member of type str.
        OPEN_INTEREST_BTC_DESC: The enum member of type str.
        TRADE_VOLUME_24H_BTC_ASC: The enum member of type str.
        TRADE_VOLUME_24H_BTC_DESC: The enum member of type str.

    """
    NAME_ASC = 'name_asc'

    NAME_DESC = 'name_desc'

    OPEN_INTEREST_BTC_ASC = 'open_interest_btc_asc'

    OPEN_INTEREST_BTC_DESC = 'open_interest_btc_desc'

    TRADE_VOLUME_24H_BTC_ASC = 'trade_volume_24h_btc_asc'

    TRADE_VOLUME_24H_BTC_DESC = 'trade_volume_24h_btc_desc'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Explorer(object):

    """Implementation of the 'Explorer' model.

    Attributes:
        name (str): The model property of type str.
        link (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "link": 'link'
    }

    _optionals = [
        'name',
        'link',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 link=APIHelper.SKIP):
        """Constructor for the Explorer class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if link is not APIHelper.SKIP:
            self.link = link 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        link = dictionary.get("link") if dictionary.get("link") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   link)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'link={(self.link if hasattr(self, "link") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'link={(self.link if hasattr(self, "link") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.community_data import CommunityData
from coingeckopublicapiv3.models.developer_data import DeveloperData
from coingeckopublicapiv3.models.image import Image
from coingeckopublicapiv3.models.links import Links
from coingeckopublicapiv3.models.market_data import MarketData
from coingeckopublicapiv3.models.ticker import Ticker


class CoinsDataBase(object):

    """Implementation of the 'CoinsDataBase' model.

    Attributes:
        id (str): coin ID
        symbol (str): coin symbol
        name (str): coin name
        web_slug (str): coin web slug
        asset_platform_id (str): coin asset platform ID
        platforms (Dict[str, str]): coin asset platform and contract address
        detail_platforms (Dict[str, str]): detailed coin asset platform and
            contract address
        block_time_in_minutes (float): blockchain block time in minutes
        hashing_algorithm (str): blockchain hashing algorithm
        categories (List[str]): coin categories
        preview_listing (bool): preview listing coin
        public_notice (str): public notice
        additional_notices (List[str]): additional notices
        localization (Dict[str, str]): coin name localization
        description (Dict[str, str]): coin description
        links (Links): links
        image (Image): coin image url
        country_origin (str): coin country of origin
        genesis_date (datetime): coin genesis date
        sentiment_votes_up_percentage (float): coin sentiment votes up
            percentage
        sentiment_votes_down_percentage (float): coin sentiment votes down
            percentage
        watchlist_portfolio_users (float): number of users watching this coin
            in portfolio
        market_cap_rank (float): coin rank by market cap
        market_data (MarketData): coin market data
        community_data (CommunityData): coin community data
        developer_data (DeveloperData): coin developer data
        status_updates (List[str]): coin status updates
        last_updated (datetime): coin last updated timestamp
        tickers (List[Ticker]): coin tickers

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "symbol": 'symbol',
        "name": 'name',
        "web_slug": 'web_slug',
        "asset_platform_id": 'asset_platform_id',
        "platforms": 'platforms',
        "detail_platforms": 'detail_platforms',
        "block_time_in_minutes": 'block_time_in_minutes',
        "hashing_algorithm": 'hashing_algorithm',
        "categories": 'categories',
        "preview_listing": 'preview_listing',
        "public_notice": 'public_notice',
        "additional_notices": 'additional_notices',
        "localization": 'localization',
        "description": 'description',
        "links": 'links',
        "image": 'image',
        "country_origin": 'country_origin',
        "genesis_date": 'genesis_date',
        "sentiment_votes_up_percentage": 'sentiment_votes_up_percentage',
        "sentiment_votes_down_percentage": 'sentiment_votes_down_percentage',
        "watchlist_portfolio_users": 'watchlist_portfolio_users',
        "market_cap_rank": 'market_cap_rank',
        "market_data": 'market_data',
        "community_data": 'community_data',
        "developer_data": 'developer_data',
        "status_updates": 'status_updates',
        "last_updated": 'last_updated',
        "tickers": 'tickers'
    }

    _optionals = [
        'id',
        'symbol',
        'name',
        'web_slug',
        'asset_platform_id',
        'platforms',
        'detail_platforms',
        'block_time_in_minutes',
        'hashing_algorithm',
        'categories',
        'preview_listing',
        'public_notice',
        'additional_notices',
        'localization',
        'description',
        'links',
        'image',
        'country_origin',
        'genesis_date',
        'sentiment_votes_up_percentage',
        'sentiment_votes_down_percentage',
        'watchlist_portfolio_users',
        'market_cap_rank',
        'market_data',
        'community_data',
        'developer_data',
        'status_updates',
        'last_updated',
        'tickers',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 web_slug=APIHelper.SKIP,
                 asset_platform_id=APIHelper.SKIP,
                 platforms=APIHelper.SKIP,
                 detail_platforms=APIHelper.SKIP,
                 block_time_in_minutes=APIHelper.SKIP,
                 hashing_algorithm=APIHelper.SKIP,
                 categories=APIHelper.SKIP,
                 preview_listing=APIHelper.SKIP,
                 public_notice=APIHelper.SKIP,
                 additional_notices=APIHelper.SKIP,
                 localization=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 links=APIHelper.SKIP,
                 image=APIHelper.SKIP,
                 country_origin=APIHelper.SKIP,
                 genesis_date=APIHelper.SKIP,
                 sentiment_votes_up_percentage=APIHelper.SKIP,
                 sentiment_votes_down_percentage=APIHelper.SKIP,
                 watchlist_portfolio_users=APIHelper.SKIP,
                 market_cap_rank=APIHelper.SKIP,
                 market_data=APIHelper.SKIP,
                 community_data=APIHelper.SKIP,
                 developer_data=APIHelper.SKIP,
                 status_updates=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP,
                 tickers=APIHelper.SKIP):
        """Constructor for the CoinsDataBase class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if name is not APIHelper.SKIP:
            self.name = name 
        if web_slug is not APIHelper.SKIP:
            self.web_slug = web_slug 
        if asset_platform_id is not APIHelper.SKIP:
            self.asset_platform_id = asset_platform_id 
        if platforms is not APIHelper.SKIP:
            self.platforms = platforms 
        if detail_platforms is not APIHelper.SKIP:
            self.detail_platforms = detail_platforms 
        if block_time_in_minutes is not APIHelper.SKIP:
            self.block_time_in_minutes = block_time_in_minutes 
        if hashing_algorithm is not APIHelper.SKIP:
            self.hashing_algorithm = hashing_algorithm 
        if categories is not APIHelper.SKIP:
            self.categories = categories 
        if preview_listing is not APIHelper.SKIP:
            self.preview_listing = preview_listing 
        if public_notice is not APIHelper.SKIP:
            self.public_notice = public_notice 
        if additional_notices is not APIHelper.SKIP:
            self.additional_notices = additional_notices 
        if localization is not APIHelper.SKIP:
            self.localization = localization 
        if description is not APIHelper.SKIP:
            self.description = description 
        if links is not APIHelper.SKIP:
            self.links = links 
        if image is not APIHelper.SKIP:
            self.image = image 
        if country_origin is not APIHelper.SKIP:
            self.country_origin = country_origin 
        if genesis_date is not APIHelper.SKIP:
            self.genesis_date = APIHelper.apply_datetime_converter(genesis_date, APIHelper.RFC3339DateTime) if genesis_date else None 
        if sentiment_votes_up_percentage is not APIHelper.SKIP:
            self.sentiment_votes_up_percentage = sentiment_votes_up_percentage 
        if sentiment_votes_down_percentage is not APIHelper.SKIP:
            self.sentiment_votes_down_percentage = sentiment_votes_down_percentage 
        if watchlist_portfolio_users is not APIHelper.SKIP:
            self.watchlist_portfolio_users = watchlist_portfolio_users 
        if market_cap_rank is not APIHelper.SKIP:
            self.market_cap_rank = market_cap_rank 
        if market_data is not APIHelper.SKIP:
            self.market_data = market_data 
        if community_data is not APIHelper.SKIP:
            self.community_data = community_data 
        if developer_data is not APIHelper.SKIP:
            self.developer_data = developer_data 
        if status_updates is not APIHelper.SKIP:
            self.status_updates = status_updates 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = APIHelper.apply_datetime_converter(last_updated, APIHelper.RFC3339DateTime) if last_updated else None 
        if tickers is not APIHelper.SKIP:
            self.tickers = tickers 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        web_slug = dictionary.get("web_slug") if dictionary.get("web_slug") else APIHelper.SKIP
        asset_platform_id = dictionary.get("asset_platform_id") if dictionary.get("asset_platform_id") else APIHelper.SKIP
        platforms = dictionary.get("platforms") if dictionary.get("platforms") else APIHelper.SKIP
        detail_platforms = dictionary.get("detail_platforms") if dictionary.get("detail_platforms") else APIHelper.SKIP
        block_time_in_minutes = dictionary.get("block_time_in_minutes") if dictionary.get("block_time_in_minutes") else APIHelper.SKIP
        hashing_algorithm = dictionary.get("hashing_algorithm") if dictionary.get("hashing_algorithm") else APIHelper.SKIP
        categories = dictionary.get("categories") if dictionary.get("categories") else APIHelper.SKIP
        preview_listing = dictionary.get("preview_listing") if "preview_listing" in dictionary.keys() else APIHelper.SKIP
        public_notice = dictionary.get("public_notice") if dictionary.get("public_notice") else APIHelper.SKIP
        additional_notices = dictionary.get("additional_notices") if dictionary.get("additional_notices") else APIHelper.SKIP
        localization = dictionary.get("localization") if dictionary.get("localization") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        links = Links.from_dictionary(dictionary.get('links')) if 'links' in dictionary.keys() else APIHelper.SKIP
        image = Image.from_dictionary(dictionary.get('image')) if 'image' in dictionary.keys() else APIHelper.SKIP
        country_origin = dictionary.get("country_origin") if dictionary.get("country_origin") else APIHelper.SKIP
        genesis_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("genesis_date")).datetime if dictionary.get("genesis_date") else APIHelper.SKIP
        sentiment_votes_up_percentage = dictionary.get("sentiment_votes_up_percentage") if dictionary.get("sentiment_votes_up_percentage") else APIHelper.SKIP
        sentiment_votes_down_percentage = dictionary.get("sentiment_votes_down_percentage") if dictionary.get("sentiment_votes_down_percentage") else APIHelper.SKIP
        watchlist_portfolio_users = dictionary.get("watchlist_portfolio_users") if dictionary.get("watchlist_portfolio_users") else APIHelper.SKIP
        market_cap_rank = dictionary.get("market_cap_rank") if dictionary.get("market_cap_rank") else APIHelper.SKIP
        market_data = MarketData.from_dictionary(dictionary.get('market_data')) if 'market_data' in dictionary.keys() else APIHelper.SKIP
        community_data = CommunityData.from_dictionary(dictionary.get('community_data')) if 'community_data' in dictionary.keys() else APIHelper.SKIP
        developer_data = DeveloperData.from_dictionary(dictionary.get('developer_data')) if 'developer_data' in dictionary.keys() else APIHelper.SKIP
        status_updates = dictionary.get("status_updates") if dictionary.get("status_updates") else APIHelper.SKIP
        last_updated = APIHelper.RFC3339DateTime.from_value(dictionary.get("last_updated")).datetime if dictionary.get("last_updated") else APIHelper.SKIP
        tickers = None
        if dictionary.get('tickers') is not None:
            tickers = [Ticker.from_dictionary(x) for x in dictionary.get('tickers')]
        else:
            tickers = APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   symbol,
                   name,
                   web_slug,
                   asset_platform_id,
                   platforms,
                   detail_platforms,
                   block_time_in_minutes,
                   hashing_algorithm,
                   categories,
                   preview_listing,
                   public_notice,
                   additional_notices,
                   localization,
                   description,
                   links,
                   image,
                   country_origin,
                   genesis_date,
                   sentiment_votes_up_percentage,
                   sentiment_votes_down_percentage,
                   watchlist_portfolio_users,
                   market_cap_rank,
                   market_data,
                   community_data,
                   developer_data,
                   status_updates,
                   last_updated,
                   tickers)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'web_slug={(self.web_slug if hasattr(self, "web_slug") else None)!r}, '
                f'asset_platform_id={(self.asset_platform_id if hasattr(self, "asset_platform_id") else None)!r}, '
                f'platforms={(self.platforms if hasattr(self, "platforms") else None)!r}, '
                f'detail_platforms={(self.detail_platforms if hasattr(self, "detail_platforms") else None)!r}, '
                f'block_time_in_minutes={(self.block_time_in_minutes if hasattr(self, "block_time_in_minutes") else None)!r}, '
                f'hashing_algorithm={(self.hashing_algorithm if hasattr(self, "hashing_algorithm") else None)!r}, '
                f'categories={(self.categories if hasattr(self, "categories") else None)!r}, '
                f'preview_listing={(self.preview_listing if hasattr(self, "preview_listing") else None)!r}, '
                f'public_notice={(self.public_notice if hasattr(self, "public_notice") else None)!r}, '
                f'additional_notices={(self.additional_notices if hasattr(self, "additional_notices") else None)!r}, '
                f'localization={(self.localization if hasattr(self, "localization") else None)!r}, '
                f'description={(self.description if hasattr(self, "description") else None)!r}, '
                f'links={(self.links if hasattr(self, "links") else None)!r}, '
                f'image={(self.image if hasattr(self, "image") else None)!r}, '
                f'country_origin={(self.country_origin if hasattr(self, "country_origin") else None)!r}, '
                f'genesis_date={(self.genesis_date if hasattr(self, "genesis_date") else None)!r}, '
                f'sentiment_votes_up_percentage={(self.sentiment_votes_up_percentage if hasattr(self, "sentiment_votes_up_percentage") else None)!r}, '
                f'sentiment_votes_down_percentage={(self.sentiment_votes_down_percentage if hasattr(self, "sentiment_votes_down_percentage") else None)!r}, '
                f'watchlist_portfolio_users={(self.watchlist_portfolio_users if hasattr(self, "watchlist_portfolio_users") else None)!r}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!r}, '
                f'market_data={(self.market_data if hasattr(self, "market_data") else None)!r}, '
                f'community_data={(self.community_data if hasattr(self, "community_data") else None)!r}, '
                f'developer_data={(self.developer_data if hasattr(self, "developer_data") else None)!r}, '
                f'status_updates={(self.status_updates if hasattr(self, "status_updates") else None)!r}, '
                f'last_updated={(self.last_updated if hasattr(self, "last_updated") else None)!r}, '
                f'tickers={(self.tickers if hasattr(self, "tickers") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'web_slug={(self.web_slug if hasattr(self, "web_slug") else None)!s}, '
                f'asset_platform_id={(self.asset_platform_id if hasattr(self, "asset_platform_id") else None)!s}, '
                f'platforms={(self.platforms if hasattr(self, "platforms") else None)!s}, '
                f'detail_platforms={(self.detail_platforms if hasattr(self, "detail_platforms") else None)!s}, '
                f'block_time_in_minutes={(self.block_time_in_minutes if hasattr(self, "block_time_in_minutes") else None)!s}, '
                f'hashing_algorithm={(self.hashing_algorithm if hasattr(self, "hashing_algorithm") else None)!s}, '
                f'categories={(self.categories if hasattr(self, "categories") else None)!s}, '
                f'preview_listing={(self.preview_listing if hasattr(self, "preview_listing") else None)!s}, '
                f'public_notice={(self.public_notice if hasattr(self, "public_notice") else None)!s}, '
                f'additional_notices={(self.additional_notices if hasattr(self, "additional_notices") else None)!s}, '
                f'localization={(self.localization if hasattr(self, "localization") else None)!s}, '
                f'description={(self.description if hasattr(self, "description") else None)!s}, '
                f'links={(self.links if hasattr(self, "links") else None)!s}, '
                f'image={(self.image if hasattr(self, "image") else None)!s}, '
                f'country_origin={(self.country_origin if hasattr(self, "country_origin") else None)!s}, '
                f'genesis_date={(self.genesis_date if hasattr(self, "genesis_date") else None)!s}, '
                f'sentiment_votes_up_percentage={(self.sentiment_votes_up_percentage if hasattr(self, "sentiment_votes_up_percentage") else None)!s}, '
                f'sentiment_votes_down_percentage={(self.sentiment_votes_down_percentage if hasattr(self, "sentiment_votes_down_percentage") else None)!s}, '
                f'watchlist_portfolio_users={(self.watchlist_portfolio_users if hasattr(self, "watchlist_portfolio_users") else None)!s}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!s}, '
                f'market_data={(self.market_data if hasattr(self, "market_data") else None)!s}, '
                f'community_data={(self.community_data if hasattr(self, "community_data") else None)!s}, '
                f'developer_data={(self.developer_data if hasattr(self, "developer_data") else None)!s}, '
                f'status_updates={(self.status_updates if hasattr(self, "status_updates") else None)!s}, '
                f'last_updated={(self.last_updated if hasattr(self, "last_updated") else None)!s}, '
                f'tickers={(self.tickers if hasattr(self, "tickers") else None)!s})')



__all__ = [
    'base_controller',
    'ping_controller',
    'simple_controller',
    'coins_controller',
    'contract_controller',
    'asset_platforms_controller',
    'categories_controller',
    'exchanges_controller',
    'derivatives_controller',
    'nf_ts_beta_controller',
    'exchange_rates_controller',
    'search_controller',
    'trending_controller',
    'global_controller',
    'companies_beta_controller',
]



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order5Enum(object):

    """Implementation of the 'order5' enum.

    Attributes:
        H24_VOLUME_USD_ASC: The enum member of type str.
        H24_VOLUME_USD_DESC: The enum member of type str.
        H24_VOLUME_NATIVE_ASC: The enum member of type str.
        H24_VOLUME_NATIVE_DESC: The enum member of type str.
        FLOOR_PRICE_NATIVE_ASC: The enum member of type str.
        FLOOR_PRICE_NATIVE_DESC: The enum member of type str.
        MARKET_CAP_NATIVE_ASC: The enum member of type str.
        MARKET_CAP_NATIVE_DESC: The enum member of type str.
        MARKET_CAP_USD_ASC: The enum member of type str.
        MARKET_CAP_USD_DESC: The enum member of type str.

    """
    H24_VOLUME_USD_ASC = 'h24_volume_usd_asc'

    H24_VOLUME_USD_DESC = 'h24_volume_usd_desc'

    H24_VOLUME_NATIVE_ASC = 'h24_volume_native_asc'

    H24_VOLUME_NATIVE_DESC = 'h24_volume_native_desc'

    FLOOR_PRICE_NATIVE_ASC = 'floor_price_native_asc'

    FLOOR_PRICE_NATIVE_DESC = 'floor_price_native_desc'

    MARKET_CAP_NATIVE_ASC = 'market_cap_native_asc'

    MARKET_CAP_NATIVE_DESC = 'market_cap_native_desc'

    MARKET_CAP_USD_ASC = 'market_cap_usd_asc'

    MARKET_CAP_USD_DESC = 'market_cap_usd_desc'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class ConvertedVolume(object):

    """Implementation of the 'ConvertedVolume' model.

    coin ticker converted volume

    Attributes:
        btc (float): The model property of type float.
        eth (float): The model property of type float.
        usd (float): The model property of type float.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "btc": 'btc',
        "eth": 'eth',
        "usd": 'usd'
    }

    _optionals = [
        'btc',
        'eth',
        'usd',
    ]

    def __init__(self,
                 btc=APIHelper.SKIP,
                 eth=APIHelper.SKIP,
                 usd=APIHelper.SKIP):
        """Constructor for the ConvertedVolume class"""

        # Initialize members of the class
        if btc is not APIHelper.SKIP:
            self.btc = btc 
        if eth is not APIHelper.SKIP:
            self.eth = eth 
        if usd is not APIHelper.SKIP:
            self.usd = usd 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        btc = dictionary.get("btc") if dictionary.get("btc") else APIHelper.SKIP
        eth = dictionary.get("eth") if dictionary.get("eth") else APIHelper.SKIP
        usd = dictionary.get("usd") if dictionary.get("usd") else APIHelper.SKIP
        # Return an object of this model
        return cls(btc,
                   eth,
                   usd)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'btc={(self.btc if hasattr(self, "btc") else None)!r}, '
                f'eth={(self.eth if hasattr(self, "eth") else None)!r}, '
                f'usd={(self.usd if hasattr(self, "usd") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'btc={(self.btc if hasattr(self, "btc") else None)!s}, '
                f'eth={(self.eth if hasattr(self, "eth") else None)!s}, '
                f'usd={(self.usd if hasattr(self, "usd") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Data4(object):

    """Implementation of the 'Data4' model.

    Attributes:
        defi_market_cap (str): defi market cap
        eth_market_cap (str): eth market cap
        defi_to_eth_ratio (str): defi to eth ratio
        trading_volume_24_h (str): defi trading volume in 24 hours
        defi_dominance (str): defi dominance
        top_coin_name (str): defi top coin name
        top_coin_defi_dominance (float): defi top coin dominance

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "defi_market_cap": 'defi_market_cap',
        "eth_market_cap": 'eth_market_cap',
        "defi_to_eth_ratio": 'defi_to_eth_ratio',
        "trading_volume_24_h": 'trading_volume_24h',
        "defi_dominance": 'defi_dominance',
        "top_coin_name": 'top_coin_name',
        "top_coin_defi_dominance": 'top_coin_defi_dominance'
    }

    _optionals = [
        'defi_market_cap',
        'eth_market_cap',
        'defi_to_eth_ratio',
        'trading_volume_24_h',
        'defi_dominance',
        'top_coin_name',
        'top_coin_defi_dominance',
    ]

    def __init__(self,
                 defi_market_cap=APIHelper.SKIP,
                 eth_market_cap=APIHelper.SKIP,
                 defi_to_eth_ratio=APIHelper.SKIP,
                 trading_volume_24_h=APIHelper.SKIP,
                 defi_dominance=APIHelper.SKIP,
                 top_coin_name=APIHelper.SKIP,
                 top_coin_defi_dominance=APIHelper.SKIP):
        """Constructor for the Data4 class"""

        # Initialize members of the class
        if defi_market_cap is not APIHelper.SKIP:
            self.defi_market_cap = defi_market_cap 
        if eth_market_cap is not APIHelper.SKIP:
            self.eth_market_cap = eth_market_cap 
        if defi_to_eth_ratio is not APIHelper.SKIP:
            self.defi_to_eth_ratio = defi_to_eth_ratio 
        if trading_volume_24_h is not APIHelper.SKIP:
            self.trading_volume_24_h = trading_volume_24_h 
        if defi_dominance is not APIHelper.SKIP:
            self.defi_dominance = defi_dominance 
        if top_coin_name is not APIHelper.SKIP:
            self.top_coin_name = top_coin_name 
        if top_coin_defi_dominance is not APIHelper.SKIP:
            self.top_coin_defi_dominance = top_coin_defi_dominance 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        defi_market_cap = dictionary.get("defi_market_cap") if dictionary.get("defi_market_cap") else APIHelper.SKIP
        eth_market_cap = dictionary.get("eth_market_cap") if dictionary.get("eth_market_cap") else APIHelper.SKIP
        defi_to_eth_ratio = dictionary.get("defi_to_eth_ratio") if dictionary.get("defi_to_eth_ratio") else APIHelper.SKIP
        trading_volume_24_h = dictionary.get("trading_volume_24h") if dictionary.get("trading_volume_24h") else APIHelper.SKIP
        defi_dominance = dictionary.get("defi_dominance") if dictionary.get("defi_dominance") else APIHelper.SKIP
        top_coin_name = dictionary.get("top_coin_name") if dictionary.get("top_coin_name") else APIHelper.SKIP
        top_coin_defi_dominance = dictionary.get("top_coin_defi_dominance") if dictionary.get("top_coin_defi_dominance") else APIHelper.SKIP
        # Return an object of this model
        return cls(defi_market_cap,
                   eth_market_cap,
                   defi_to_eth_ratio,
                   trading_volume_24_h,
                   defi_dominance,
                   top_coin_name,
                   top_coin_defi_dominance)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'defi_market_cap={(self.defi_market_cap if hasattr(self, "defi_market_cap") else None)!r}, '
                f'eth_market_cap={(self.eth_market_cap if hasattr(self, "eth_market_cap") else None)!r}, '
                f'defi_to_eth_ratio={(self.defi_to_eth_ratio if hasattr(self, "defi_to_eth_ratio") else None)!r}, '
                f'trading_volume_24_h={(self.trading_volume_24_h if hasattr(self, "trading_volume_24_h") else None)!r}, '
                f'defi_dominance={(self.defi_dominance if hasattr(self, "defi_dominance") else None)!r}, '
                f'top_coin_name={(self.top_coin_name if hasattr(self, "top_coin_name") else None)!r}, '
                f'top_coin_defi_dominance={(self.top_coin_defi_dominance if hasattr(self, "top_coin_defi_dominance") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'defi_market_cap={(self.defi_market_cap if hasattr(self, "defi_market_cap") else None)!s}, '
                f'eth_market_cap={(self.eth_market_cap if hasattr(self, "eth_market_cap") else None)!s}, '
                f'defi_to_eth_ratio={(self.defi_to_eth_ratio if hasattr(self, "defi_to_eth_ratio") else None)!s}, '
                f'trading_volume_24_h={(self.trading_volume_24_h if hasattr(self, "trading_volume_24_h") else None)!s}, '
                f'defi_dominance={(self.defi_dominance if hasattr(self, "defi_dominance") else None)!s}, '
                f'top_coin_name={(self.top_coin_name if hasattr(self, "top_coin_name") else None)!s}, '
                f'top_coin_defi_dominance={(self.top_coin_defi_dominance if hasattr(self, "top_coin_defi_dominance") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from enum import Enum
from apimatic_core.http.configurations.http_client_configuration import HttpClientConfiguration
from apimatic_requests_client_adapter.requests_client import RequestsClient


class Environment(Enum):
    """An enum for SDK environments"""
    PRODUCTION = 0


class Server(Enum):
    """An enum for API servers"""
    DEFAULT = 0


class Configuration(HttpClientConfiguration):
    """A class used for configuring the SDK by a user.
    """

    @property
    def environment(self):
        return self._environment

    @property
    def api_key_auth_credentials(self):
        return self._api_key_auth_credentials

    @property
    def api_key_query_param_credentials(self):
        return self._api_key_query_param_credentials

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=None, retry_methods=None,
                 environment=Environment.PRODUCTION,
                 api_key_auth_credentials=None,
                 api_key_query_param_credentials=None):
        if retry_methods is None:
            retry_methods = ['GET', 'PUT']

        if retry_statuses is None:
            retry_statuses = [408, 413, 429, 500, 502, 503, 504, 521, 522, 524]

        super().__init__(http_client_instance,
                         override_http_client_configuration, http_call_back,
                         timeout, max_retries, backoff_factor, retry_statuses,
                         retry_methods)

        # Current API environment
        self._environment = environment

        # The object holding Custom Header Signature credentials
        self._api_key_auth_credentials = api_key_auth_credentials

        # The object holding Custom Query Parameter credentials
        self._api_key_query_param_credentials = api_key_query_param_credentials

        # The Http Client to use for making requests.
        self.set_http_client(self.create_http_client())

    def clone_with(self, http_client_instance=None,
                   override_http_client_configuration=None, http_call_back=None,
                   timeout=None, max_retries=None, backoff_factor=None,
                   retry_statuses=None, retry_methods=None, environment=None,
                   api_key_auth_credentials=None,
                   api_key_query_param_credentials=None):
        http_client_instance = http_client_instance or self.http_client_instance
        override_http_client_configuration = override_http_client_configuration or self.override_http_client_configuration
        http_call_back = http_call_back or self.http_callback
        timeout = timeout or self.timeout
        max_retries = max_retries or self.max_retries
        backoff_factor = backoff_factor or self.backoff_factor
        retry_statuses = retry_statuses or self.retry_statuses
        retry_methods = retry_methods or self.retry_methods
        environment = environment or self.environment
        api_key_auth_credentials = api_key_auth_credentials or self.api_key_auth_credentials
        api_key_query_param_credentials = api_key_query_param_credentials or self.api_key_query_param_credentials
        return Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            environment=environment,
            api_key_auth_credentials=api_key_auth_credentials,
            api_key_query_param_credentials=api_key_query_param_credentials
        )

    def create_http_client(self):
        return RequestsClient(
            timeout=self.timeout, max_retries=self.max_retries,
            backoff_factor=self.backoff_factor, retry_statuses=self.retry_statuses,
            retry_methods=self.retry_methods,
            http_client_instance=self.http_client_instance,
            override_http_client_configuration=self.override_http_client_configuration,
            response_factory=self.http_response_factory
        )

    # All the environments the SDK can run in
    environments = {
        Environment.PRODUCTION: {
            Server.DEFAULT: 'https://api.coingecko.com/api/v3'
        }
    }

    def get_base_uri(self, server=Server.DEFAULT):
        """Generates the appropriate base URI for the environment and the
        server.

        Args:
            server (Configuration.Server): The server enum for which the base
            URI is required.

        Returns:
            String: The base URI.

        """
        return self.environments[self.environment][server]



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class CodeAdditionsDeletions4Weeks1(object):

    """Implementation of the 'CodeAdditionsDeletions4Weeks1' model.

    coin code additions deletions 4 weeks

    Attributes:
        additions (float): The model property of type float.
        deletions (float): The model property of type float.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additions": 'additions',
        "deletions": 'deletions'
    }

    _optionals = [
        'additions',
        'deletions',
    ]

    def __init__(self,
                 additions=APIHelper.SKIP,
                 deletions=APIHelper.SKIP):
        """Constructor for the CodeAdditionsDeletions4Weeks1 class"""

        # Initialize members of the class
        if additions is not APIHelper.SKIP:
            self.additions = additions 
        if deletions is not APIHelper.SKIP:
            self.deletions = deletions 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        additions = dictionary.get("additions") if dictionary.get("additions") else APIHelper.SKIP
        deletions = dictionary.get("deletions") if dictionary.get("deletions") else APIHelper.SKIP
        # Return an object of this model
        return cls(additions,
                   deletions)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'additions={(self.additions if hasattr(self, "additions") else None)!r}, '
                f'deletions={(self.deletions if hasattr(self, "deletions") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'additions={(self.additions if hasattr(self, "additions") else None)!s}, '
                f'deletions={(self.deletions if hasattr(self, "deletions") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DexPairFormatEnum(object):

    """Implementation of the 'dex_pair_format' enum.

    Attributes:
        CONTRACT_ADDRESS: The enum member of type str.
        SYMBOL: The enum member of type str.

    """
    CONTRACT_ADDRESS = 'contract_address'

    SYMBOL = 'symbol'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PrecisionEnum(object):

    """Implementation of the 'precision' enum.

    Attributes:
        FULL: The enum member of type str.
        ENUM_0: The enum member of type str.
        ENUM_1: The enum member of type str.
        ENUM_2: The enum member of type str.
        ENUM_3: The enum member of type str.
        ENUM_4: The enum member of type str.
        ENUM_5: The enum member of type str.
        ENUM_6: The enum member of type str.
        ENUM_7: The enum member of type str.
        ENUM_8: The enum member of type str.
        ENUM_9: The enum member of type str.
        ENUM_10: The enum member of type str.
        ENUM_11: The enum member of type str.
        ENUM_12: The enum member of type str.
        ENUM_13: The enum member of type str.
        ENUM_14: The enum member of type str.
        ENUM_15: The enum member of type str.
        ENUM_16: The enum member of type str.
        ENUM_17: The enum member of type str.
        ENUM_18: The enum member of type str.

    """
    FULL = 'full'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'

    ENUM_5 = '5'

    ENUM_6 = '6'

    ENUM_7 = '7'

    ENUM_8 = '8'

    ENUM_9 = '9'

    ENUM_10 = '10'

    ENUM_11 = '11'

    ENUM_12 = '12'

    ENUM_13 = '13'

    ENUM_14 = '14'

    ENUM_15 = '15'

    ENUM_16 = '16'

    ENUM_17 = '17'

    ENUM_18 = '18'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Market1(object):

    """Implementation of the 'Market1' model.

    coin ticker exchange

    Attributes:
        name (str): exchange name
        identifier (str): exchange identifier
        has_trading_incentive (bool): exchange trading incentive
        logo (str): exchange image url

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "identifier": 'identifier',
        "has_trading_incentive": 'has_trading_incentive',
        "logo": 'logo'
    }

    _optionals = [
        'logo',
    ]

    def __init__(self,
                 name=None,
                 identifier=None,
                 has_trading_incentive=None,
                 logo=APIHelper.SKIP):
        """Constructor for the Market1 class"""

        # Initialize members of the class
        self.name = name 
        self.identifier = identifier 
        self.has_trading_incentive = has_trading_incentive 
        if logo is not APIHelper.SKIP:
            self.logo = logo 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else None
        identifier = dictionary.get("identifier") if dictionary.get("identifier") else None
        has_trading_incentive = dictionary.get("has_trading_incentive") if "has_trading_incentive" in dictionary.keys() else None
        logo = dictionary.get("logo") if dictionary.get("logo") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   identifier,
                   has_trading_incentive,
                   logo)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={self.name!r}, '
                f'identifier={self.identifier!r}, '
                f'has_trading_incentive={self.has_trading_incentive!r}, '
                f'logo={(self.logo if hasattr(self, "logo") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={self.name!s}, '
                f'identifier={self.identifier!s}, '
                f'has_trading_incentive={self.has_trading_incentive!s}, '
                f'logo={(self.logo if hasattr(self, "logo") else None)!s})')



__all__ = [
    'ping',
    'simple_price',
    'simple_token_price',
    'coins_markets',
    'coins_data_base',
    'coins_tickers',
    'coins_historical_data',
    'coins_market_chart',
    'coins_market_chart_range',
    'token_lists',
    'categories_list',
    'categories',
    'exchanges',
    'exchanges_list',
    'exchange_data',
    'derivatives_tickers_list',
    'derivatives_exchanges',
    'derivatives_exchanges_id',
    'derivatives_exchanges_list',
    'nft_list',
    'nft_data',
    'exchange_rates',
    'search',
    'trending_search',
    'mglobal',
    'global_de_fi',
    'companies_treasury',
    'asset_platform',
    'ath',
    'ath_1',
    'ath_change_percentage',
    'ath_change_percentage_1',
    'ath_date',
    'ath_date_1',
    'atl',
    'atl_change_percentage',
    'atl_date',
    'banner_image',
    'categories_1',
    'categories_2',
    'code_additions_deletions_4_weeks',
    'code_additions_deletions_4_weeks_1',
    'coin',
    'coin_1',
    'coins_list',
    'community_data',
    'community_data_1',
    'company',
    'converted_last',
    'converted_volume',
    'current_price',
    'current_price_1',
    'data',
    'data_1',
    'data_2',
    'data_3',
    'data_4',
    'developer_data',
    'developer_data_1',
    'exchanges_1',
    'explorer',
    'floor_price',
    'floor_price_14_d_percentage_change',
    'floor_price_1_y_percentage_change',
    'floor_price_24_h_percentage_change',
    'floor_price_30_d_percentage_change',
    'floor_price_60_d_percentage_change',
    'floor_price_7_d_percentage_change',
    'fully_diluted_valuation',
    'high_24_h',
    'image',
    'image_1',
    'image_2',
    'image_3',
    'links',
    'links_1',
    'low_24_h',
    'market',
    'market_1',
    'market_cap',
    'market_cap_24_h_percentage_change',
    'market_cap_1',
    'market_cap_2',
    'market_cap_change_24_h_in_currency',
    'market_cap_change_percentage_24_h',
    'market_cap_change_percentage_24_h_in_currency',
    'market_cap_percentage',
    'market_data',
    'market_data_1',
    'nft',
    'nft_1',
    'price_change_percentage_14_d_in_currency',
    'price_change_percentage_1_h_in_currency',
    'price_change_percentage_1_y_in_currency',
    'price_change_percentage_200_d_in_currency',
    'price_change_percentage_24_h',
    'price_change_percentage_24_h_in_currency',
    'price_change_percentage_30_d_in_currency',
    'price_change_percentage_60_d_in_currency',
    'price_change_percentage_7_d_in_currency',
    'public_interest_stats',
    'rates',
    'repos_url',
    'ticker',
    'ticker_1',
    'token',
    'total_market_cap',
    'total_volume',
    'total_volume_1',
    'total_volume_2',
    'volume_24_h',
    'volume_24_h_percentage_change',
    'coin_id_enum',
    'days_enum',
    'dex_pair_format_enum',
    'filter_enum',
    'include_tickers_enum',
    'include_tokens_enum',
    'interval_enum',
    'locale_enum',
    'order_enum',
    'order_1_enum',
    'order_2_enum',
    'order_3_enum',
    'order_4_enum',
    'order_5_enum',
    'precision_enum',
    'status_enum',
]



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.data import Data


class Coin1(object):

    """Implementation of the 'Coin1' model.

    Attributes:
        id (str): coin ID
        coin_id (float): The model property of type float.
        name (str): coin name
        symbol (str): coin symbol
        market_cap_rank (float): coin market cap rank
        thumb (str): coin thumb image url
        small (str): coin small image url
        large (str): coin large image url
        slug (str): coin web slug
        price_btc (float): coin price in btc
        score (float): coin sequence in the list
        data (Data): The model property of type Data.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "coin_id": 'coin_id',
        "name": 'name',
        "symbol": 'symbol',
        "market_cap_rank": 'market_cap_rank',
        "thumb": 'thumb',
        "small": 'small',
        "large": 'large',
        "slug": 'slug',
        "price_btc": 'price_btc',
        "score": 'score',
        "data": 'data'
    }

    _optionals = [
        'id',
        'coin_id',
        'name',
        'symbol',
        'market_cap_rank',
        'thumb',
        'small',
        'large',
        'slug',
        'price_btc',
        'score',
        'data',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 coin_id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 market_cap_rank=APIHelper.SKIP,
                 thumb=APIHelper.SKIP,
                 small=APIHelper.SKIP,
                 large=APIHelper.SKIP,
                 slug=APIHelper.SKIP,
                 price_btc=APIHelper.SKIP,
                 score=APIHelper.SKIP,
                 data=APIHelper.SKIP):
        """Constructor for the Coin1 class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if coin_id is not APIHelper.SKIP:
            self.coin_id = coin_id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if market_cap_rank is not APIHelper.SKIP:
            self.market_cap_rank = market_cap_rank 
        if thumb is not APIHelper.SKIP:
            self.thumb = thumb 
        if small is not APIHelper.SKIP:
            self.small = small 
        if large is not APIHelper.SKIP:
            self.large = large 
        if slug is not APIHelper.SKIP:
            self.slug = slug 
        if price_btc is not APIHelper.SKIP:
            self.price_btc = price_btc 
        if score is not APIHelper.SKIP:
            self.score = score 
        if data is not APIHelper.SKIP:
            self.data = data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        coin_id = dictionary.get("coin_id") if dictionary.get("coin_id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        market_cap_rank = dictionary.get("market_cap_rank") if dictionary.get("market_cap_rank") else APIHelper.SKIP
        thumb = dictionary.get("thumb") if dictionary.get("thumb") else APIHelper.SKIP
        small = dictionary.get("small") if dictionary.get("small") else APIHelper.SKIP
        large = dictionary.get("large") if dictionary.get("large") else APIHelper.SKIP
        slug = dictionary.get("slug") if dictionary.get("slug") else APIHelper.SKIP
        price_btc = dictionary.get("price_btc") if dictionary.get("price_btc") else APIHelper.SKIP
        score = dictionary.get("score") if dictionary.get("score") else APIHelper.SKIP
        data = Data.from_dictionary(dictionary.get('data')) if 'data' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   coin_id,
                   name,
                   symbol,
                   market_cap_rank,
                   thumb,
                   small,
                   large,
                   slug,
                   price_btc,
                   score,
                   data)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'coin_id={(self.coin_id if hasattr(self, "coin_id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!r}, '
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!r}, '
                f'small={(self.small if hasattr(self, "small") else None)!r}, '
                f'large={(self.large if hasattr(self, "large") else None)!r}, '
                f'slug={(self.slug if hasattr(self, "slug") else None)!r}, '
                f'price_btc={(self.price_btc if hasattr(self, "price_btc") else None)!r}, '
                f'score={(self.score if hasattr(self, "score") else None)!r}, '
                f'data={(self.data if hasattr(self, "data") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'coin_id={(self.coin_id if hasattr(self, "coin_id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!s}, '
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!s}, '
                f'small={(self.small if hasattr(self, "small") else None)!s}, '
                f'large={(self.large if hasattr(self, "large") else None)!s}, '
                f'slug={(self.slug if hasattr(self, "slug") else None)!s}, '
                f'price_btc={(self.price_btc if hasattr(self, "price_btc") else None)!s}, '
                f'score={(self.score if hasattr(self, "score") else None)!s}, '
                f'data={(self.data if hasattr(self, "data") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Rates(object):

    """Implementation of the 'Rates' model.

    Attributes:
        name (str): name of the currency
        unit (str): unit of the currency
        value (float): value of the currency
        mtype (str): type of the currency

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "unit": 'unit',
        "value": 'value',
        "mtype": 'type'
    }

    _optionals = [
        'name',
        'unit',
        'value',
        'mtype',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 unit=APIHelper.SKIP,
                 value=APIHelper.SKIP,
                 mtype=APIHelper.SKIP):
        """Constructor for the Rates class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if unit is not APIHelper.SKIP:
            self.unit = unit 
        if value is not APIHelper.SKIP:
            self.value = value 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        unit = dictionary.get("unit") if dictionary.get("unit") else APIHelper.SKIP
        value = dictionary.get("value") if dictionary.get("value") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   unit,
                   value,
                   mtype)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'unit={(self.unit if hasattr(self, "unit") else None)!r}, '
                f'value={(self.value if hasattr(self, "value") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'unit={(self.unit if hasattr(self, "unit") else None)!s}, '
                f'value={(self.value if hasattr(self, "value") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.nft_list import NFTList
from coingeckopublicapiv3.models.nft_data import NFTData


class NFTsBetaController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(NFTsBetaController, self).__init__(config)

    def nfts_list(self,
                  order=None,
                  per_page=None,
                  page=None):
        """Does a GET request to /nfts/list.

        This endpoint allows you to **query all supported NFTs with ID,
        contract address, name, asset platform ID and symbol on CoinGecko**

        Args:
            order (Order5Enum, optional): use this to sort the order of
                responses
            per_page (int, optional): total results per page <br> Valid
                values: 1...250
            page (int, optional): page through results

        Returns:
            NFTList: Response from the API. List all NFTs categories

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/nfts/list')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('order')
                         .value(order))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(NFTList.from_dictionary)
        ).execute()

    def nfts_id(self,
                id):
        """Does a GET request to /nfts/{id}.

        This endpoint allows you to **query all the NFT data (name, floor
        price, 24hr volume ...) based on the NFT collection ID**

        Args:
            id (str): NFTs ID <br> *refers to
                [`/nfts/list`](/reference/nfts-list).

        Returns:
            NFTData: Response from the API. Get NFTs data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/nfts/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(NFTData.from_dictionary)
        ).execute()

    def nfts_contract_address(self,
                              asset_platform_id,
                              contract_address):
        """Does a GET request to /nfts/{asset_platform_id}/contract/{contract_address}.

        This endpoint allows you to **query all the NFT data (name, floor
        price, 24hr volume ...) based on the NFT collection contract address
        and respective asset platform**

        Args:
            asset_platform_id (str): asset platform ID <br> *refers to
                [`/asset_platforms`](/reference/asset-platforms-list)
            contract_address (str): the contract address of token

        Returns:
            NFTData: Response from the API. Get NFTs data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/nfts/{asset_platform_id}/contract/{contract_address}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('asset_platform_id')
                            .value(asset_platform_id)
                            .should_encode(True))
            .template_param(Parameter()
                            .key('contract_address')
                            .value(contract_address)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(NFTData.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Exchanges(object):

    """Implementation of the 'Exchanges' model.

    Attributes:
        id (str): exchange ID
        name (str): exchange name
        year_established (float): exchange established year
        country (str): exchange country
        description (str): exchange description
        url (str): exchange website url
        image (str): exchange image url
        has_trading_incentive (bool): exchange trading incentive
        trust_score (float): exchange trust score
        trust_score_rank (float): exchange trust score rank
        trade_volume_24_h_btc (float): exchange trade volume in BTC in 24 hours

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name',
        "year_established": 'year_established',
        "country": 'country',
        "description": 'description',
        "url": 'url',
        "image": 'image',
        "has_trading_incentive": 'has_trading_incentive',
        "trust_score": 'trust_score',
        "trust_score_rank": 'trust_score_rank',
        "trade_volume_24_h_btc": 'trade_volume_24h_btc'
    }

    _optionals = [
        'id',
        'name',
        'year_established',
        'country',
        'description',
        'url',
        'image',
        'has_trading_incentive',
        'trust_score',
        'trust_score_rank',
        'trade_volume_24_h_btc',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 year_established=APIHelper.SKIP,
                 country=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 url=APIHelper.SKIP,
                 image=APIHelper.SKIP,
                 has_trading_incentive=APIHelper.SKIP,
                 trust_score=APIHelper.SKIP,
                 trust_score_rank=APIHelper.SKIP,
                 trade_volume_24_h_btc=APIHelper.SKIP):
        """Constructor for the Exchanges class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if year_established is not APIHelper.SKIP:
            self.year_established = year_established 
        if country is not APIHelper.SKIP:
            self.country = country 
        if description is not APIHelper.SKIP:
            self.description = description 
        if url is not APIHelper.SKIP:
            self.url = url 
        if image is not APIHelper.SKIP:
            self.image = image 
        if has_trading_incentive is not APIHelper.SKIP:
            self.has_trading_incentive = has_trading_incentive 
        if trust_score is not APIHelper.SKIP:
            self.trust_score = trust_score 
        if trust_score_rank is not APIHelper.SKIP:
            self.trust_score_rank = trust_score_rank 
        if trade_volume_24_h_btc is not APIHelper.SKIP:
            self.trade_volume_24_h_btc = trade_volume_24_h_btc 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        year_established = dictionary.get("year_established") if dictionary.get("year_established") else APIHelper.SKIP
        country = dictionary.get("country") if dictionary.get("country") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        url = dictionary.get("url") if dictionary.get("url") else APIHelper.SKIP
        image = dictionary.get("image") if dictionary.get("image") else APIHelper.SKIP
        has_trading_incentive = dictionary.get("has_trading_incentive") if "has_trading_incentive" in dictionary.keys() else APIHelper.SKIP
        trust_score = dictionary.get("trust_score") if dictionary.get("trust_score") else APIHelper.SKIP
        trust_score_rank = dictionary.get("trust_score_rank") if dictionary.get("trust_score_rank") else APIHelper.SKIP
        trade_volume_24_h_btc = dictionary.get("trade_volume_24h_btc") if dictionary.get("trade_volume_24h_btc") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name,
                   year_established,
                   country,
                   description,
                   url,
                   image,
                   has_trading_incentive,
                   trust_score,
                   trust_score_rank,
                   trade_volume_24_h_btc)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'year_established={(self.year_established if hasattr(self, "year_established") else None)!r}, '
                f'country={(self.country if hasattr(self, "country") else None)!r}, '
                f'description={(self.description if hasattr(self, "description") else None)!r}, '
                f'url={(self.url if hasattr(self, "url") else None)!r}, '
                f'image={(self.image if hasattr(self, "image") else None)!r}, '
                f'has_trading_incentive={(self.has_trading_incentive if hasattr(self, "has_trading_incentive") else None)!r}, '
                f'trust_score={(self.trust_score if hasattr(self, "trust_score") else None)!r}, '
                f'trust_score_rank={(self.trust_score_rank if hasattr(self, "trust_score_rank") else None)!r}, '
                f'trade_volume_24_h_btc={(self.trade_volume_24_h_btc if hasattr(self, "trade_volume_24_h_btc") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'year_established={(self.year_established if hasattr(self, "year_established") else None)!s}, '
                f'country={(self.country if hasattr(self, "country") else None)!s}, '
                f'description={(self.description if hasattr(self, "description") else None)!s}, '
                f'url={(self.url if hasattr(self, "url") else None)!s}, '
                f'image={(self.image if hasattr(self, "image") else None)!s}, '
                f'has_trading_incentive={(self.has_trading_incentive if hasattr(self, "has_trading_incentive") else None)!s}, '
                f'trust_score={(self.trust_score if hasattr(self, "trust_score") else None)!s}, '
                f'trust_score_rank={(self.trust_score_rank if hasattr(self, "trust_score_rank") else None)!s}, '
                f'trade_volume_24_h_btc={(self.trade_volume_24_h_btc if hasattr(self, "trade_volume_24_h_btc") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Categories(object):

    """Implementation of the 'Categories' model.

    Attributes:
        id (str): category ID
        name (str): category name
        market_cap (float): category market cap
        market_cap_change_24_h (float): category market cap change in 24 hours
        content (str): category description
        top_3_coins_id (List[str]): IDs of top 3 coins in the category
        top_3_coins (List[str]): images of top 3 coins in the category
        volume_24_h (float): category volume in 24 hours
        updated_at (str): category last updated time

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name',
        "market_cap": 'market_cap',
        "market_cap_change_24_h": 'market_cap_change_24h',
        "content": 'content',
        "top_3_coins_id": 'top_3_coins_id',
        "top_3_coins": 'top_3_coins',
        "volume_24_h": 'volume_24h',
        "updated_at": 'updated_at'
    }

    _optionals = [
        'id',
        'name',
        'market_cap',
        'market_cap_change_24_h',
        'content',
        'top_3_coins_id',
        'top_3_coins',
        'volume_24_h',
        'updated_at',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 market_cap=APIHelper.SKIP,
                 market_cap_change_24_h=APIHelper.SKIP,
                 content=APIHelper.SKIP,
                 top_3_coins_id=APIHelper.SKIP,
                 top_3_coins=APIHelper.SKIP,
                 volume_24_h=APIHelper.SKIP,
                 updated_at=APIHelper.SKIP):
        """Constructor for the Categories class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if market_cap is not APIHelper.SKIP:
            self.market_cap = market_cap 
        if market_cap_change_24_h is not APIHelper.SKIP:
            self.market_cap_change_24_h = market_cap_change_24_h 
        if content is not APIHelper.SKIP:
            self.content = content 
        if top_3_coins_id is not APIHelper.SKIP:
            self.top_3_coins_id = top_3_coins_id 
        if top_3_coins is not APIHelper.SKIP:
            self.top_3_coins = top_3_coins 
        if volume_24_h is not APIHelper.SKIP:
            self.volume_24_h = volume_24_h 
        if updated_at is not APIHelper.SKIP:
            self.updated_at = updated_at 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        market_cap = dictionary.get("market_cap") if dictionary.get("market_cap") else APIHelper.SKIP
        market_cap_change_24_h = dictionary.get("market_cap_change_24h") if dictionary.get("market_cap_change_24h") else APIHelper.SKIP
        content = dictionary.get("content") if dictionary.get("content") else APIHelper.SKIP
        top_3_coins_id = dictionary.get("top_3_coins_id") if dictionary.get("top_3_coins_id") else APIHelper.SKIP
        top_3_coins = dictionary.get("top_3_coins") if dictionary.get("top_3_coins") else APIHelper.SKIP
        volume_24_h = dictionary.get("volume_24h") if dictionary.get("volume_24h") else APIHelper.SKIP
        updated_at = dictionary.get("updated_at") if dictionary.get("updated_at") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name,
                   market_cap,
                   market_cap_change_24_h,
                   content,
                   top_3_coins_id,
                   top_3_coins,
                   volume_24_h,
                   updated_at)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!r}, '
                f'market_cap_change_24_h={(self.market_cap_change_24_h if hasattr(self, "market_cap_change_24_h") else None)!r}, '
                f'content={(self.content if hasattr(self, "content") else None)!r}, '
                f'top_3_coins_id={(self.top_3_coins_id if hasattr(self, "top_3_coins_id") else None)!r}, '
                f'top_3_coins={(self.top_3_coins if hasattr(self, "top_3_coins") else None)!r}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!r}, '
                f'updated_at={(self.updated_at if hasattr(self, "updated_at") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!s}, '
                f'market_cap_change_24_h={(self.market_cap_change_24_h if hasattr(self, "market_cap_change_24_h") else None)!s}, '
                f'content={(self.content if hasattr(self, "content") else None)!s}, '
                f'top_3_coins_id={(self.top_3_coins_id if hasattr(self, "top_3_coins_id") else None)!s}, '
                f'top_3_coins={(self.top_3_coins if hasattr(self, "top_3_coins") else None)!s}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!s}, '
                f'updated_at={(self.updated_at if hasattr(self, "updated_at") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeTokensEnum(object):

    """Implementation of the 'include_tokens' enum.

    Attributes:
        TOP: The enum member of type str.
        ALL: The enum member of type str.

    """
    TOP = 'top'

    ALL = 'all'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Company(object):

    """Implementation of the 'Company' model.

    Attributes:
        name (str): company name
        symbol (str): company symbol
        country (str): company incorporated country
        total_holdings (float): total btc/eth holdings of company
        total_entry_value_usd (float): total entry value in usd
        total_current_value_usd (float): total current value of btc/eth
            holdings in usd
        percentage_of_total_supply (float): percentage of total btc/eth supply

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "symbol": 'symbol',
        "country": 'country',
        "total_holdings": 'total_holdings',
        "total_entry_value_usd": 'total_entry_value_usd',
        "total_current_value_usd": 'total_current_value_usd',
        "percentage_of_total_supply": 'percentage_of_total_supply'
    }

    _optionals = [
        'name',
        'symbol',
        'country',
        'total_holdings',
        'total_entry_value_usd',
        'total_current_value_usd',
        'percentage_of_total_supply',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 country=APIHelper.SKIP,
                 total_holdings=APIHelper.SKIP,
                 total_entry_value_usd=APIHelper.SKIP,
                 total_current_value_usd=APIHelper.SKIP,
                 percentage_of_total_supply=APIHelper.SKIP):
        """Constructor for the Company class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if country is not APIHelper.SKIP:
            self.country = country 
        if total_holdings is not APIHelper.SKIP:
            self.total_holdings = total_holdings 
        if total_entry_value_usd is not APIHelper.SKIP:
            self.total_entry_value_usd = total_entry_value_usd 
        if total_current_value_usd is not APIHelper.SKIP:
            self.total_current_value_usd = total_current_value_usd 
        if percentage_of_total_supply is not APIHelper.SKIP:
            self.percentage_of_total_supply = percentage_of_total_supply 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        country = dictionary.get("country") if dictionary.get("country") else APIHelper.SKIP
        total_holdings = dictionary.get("total_holdings") if dictionary.get("total_holdings") else APIHelper.SKIP
        total_entry_value_usd = dictionary.get("total_entry_value_usd") if dictionary.get("total_entry_value_usd") else APIHelper.SKIP
        total_current_value_usd = dictionary.get("total_current_value_usd") if dictionary.get("total_current_value_usd") else APIHelper.SKIP
        percentage_of_total_supply = dictionary.get("percentage_of_total_supply") if dictionary.get("percentage_of_total_supply") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   symbol,
                   country,
                   total_holdings,
                   total_entry_value_usd,
                   total_current_value_usd,
                   percentage_of_total_supply)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'country={(self.country if hasattr(self, "country") else None)!r}, '
                f'total_holdings={(self.total_holdings if hasattr(self, "total_holdings") else None)!r}, '
                f'total_entry_value_usd={(self.total_entry_value_usd if hasattr(self, "total_entry_value_usd") else None)!r}, '
                f'total_current_value_usd={(self.total_current_value_usd if hasattr(self, "total_current_value_usd") else None)!r}, '
                f'percentage_of_total_supply={(self.percentage_of_total_supply if hasattr(self, "percentage_of_total_supply") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'country={(self.country if hasattr(self, "country") else None)!s}, '
                f'total_holdings={(self.total_holdings if hasattr(self, "total_holdings") else None)!s}, '
                f'total_entry_value_usd={(self.total_entry_value_usd if hasattr(self, "total_entry_value_usd") else None)!s}, '
                f'total_current_value_usd={(self.total_current_value_usd if hasattr(self, "total_current_value_usd") else None)!s}, '
                f'percentage_of_total_supply={(self.percentage_of_total_supply if hasattr(self, "percentage_of_total_supply") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FilterEnum(object):

    """Implementation of the 'filter' enum.

    Attributes:
        NFT: The enum member of type str.

    """
    NFT = 'nft'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderEnum(object):

    """Implementation of the 'order' enum.

    Attributes:
        MARKET_CAP_ASC: The enum member of type str.
        MARKET_CAP_DESC: The enum member of type str.
        VOLUME_ASC: The enum member of type str.
        VOLUME_DESC: The enum member of type str.
        ID_ASC: The enum member of type str.
        ID_DESC: The enum member of type str.

    """
    MARKET_CAP_ASC = 'market_cap_asc'

    MARKET_CAP_DESC = 'market_cap_desc'

    VOLUME_ASC = 'volume_asc'

    VOLUME_DESC = 'volume_desc'

    ID_ASC = 'id_asc'

    ID_DESC = 'id_desc'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.code_additions_deletions_4_weeks_1 import CodeAdditionsDeletions4Weeks1


class DeveloperData1(object):

    """Implementation of the 'DeveloperData1' model.

    coin developer data

    Attributes:
        forks (float): coin repository forks
        stars (float): coin repository stars
        subscribers (float): coin repository subscribers
        total_issues (float): coin repository total issues
        closed_issues (float): coin repository closed issues
        pull_requests_merged (float): coin repository pull requests merged
        pull_request_contributors (float): coin repository pull request
            contributors
        code_additions_deletions_4_weeks (CodeAdditionsDeletions4Weeks1): coin
            code additions deletions 4 weeks
        commit_count_4_weeks (float): coin commit count 4 weeks

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "forks": 'forks',
        "stars": 'stars',
        "subscribers": 'subscribers',
        "total_issues": 'total_issues',
        "closed_issues": 'closed_issues',
        "pull_requests_merged": 'pull_requests_merged',
        "pull_request_contributors": 'pull_request_contributors',
        "code_additions_deletions_4_weeks": 'code_additions_deletions_4_weeks',
        "commit_count_4_weeks": 'commit_count_4_weeks'
    }

    _optionals = [
        'forks',
        'stars',
        'subscribers',
        'total_issues',
        'closed_issues',
        'pull_requests_merged',
        'pull_request_contributors',
        'code_additions_deletions_4_weeks',
        'commit_count_4_weeks',
    ]

    def __init__(self,
                 forks=APIHelper.SKIP,
                 stars=APIHelper.SKIP,
                 subscribers=APIHelper.SKIP,
                 total_issues=APIHelper.SKIP,
                 closed_issues=APIHelper.SKIP,
                 pull_requests_merged=APIHelper.SKIP,
                 pull_request_contributors=APIHelper.SKIP,
                 code_additions_deletions_4_weeks=APIHelper.SKIP,
                 commit_count_4_weeks=APIHelper.SKIP):
        """Constructor for the DeveloperData1 class"""

        # Initialize members of the class
        if forks is not APIHelper.SKIP:
            self.forks = forks 
        if stars is not APIHelper.SKIP:
            self.stars = stars 
        if subscribers is not APIHelper.SKIP:
            self.subscribers = subscribers 
        if total_issues is not APIHelper.SKIP:
            self.total_issues = total_issues 
        if closed_issues is not APIHelper.SKIP:
            self.closed_issues = closed_issues 
        if pull_requests_merged is not APIHelper.SKIP:
            self.pull_requests_merged = pull_requests_merged 
        if pull_request_contributors is not APIHelper.SKIP:
            self.pull_request_contributors = pull_request_contributors 
        if code_additions_deletions_4_weeks is not APIHelper.SKIP:
            self.code_additions_deletions_4_weeks = code_additions_deletions_4_weeks 
        if commit_count_4_weeks is not APIHelper.SKIP:
            self.commit_count_4_weeks = commit_count_4_weeks 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        forks = dictionary.get("forks") if dictionary.get("forks") else APIHelper.SKIP
        stars = dictionary.get("stars") if dictionary.get("stars") else APIHelper.SKIP
        subscribers = dictionary.get("subscribers") if dictionary.get("subscribers") else APIHelper.SKIP
        total_issues = dictionary.get("total_issues") if dictionary.get("total_issues") else APIHelper.SKIP
        closed_issues = dictionary.get("closed_issues") if dictionary.get("closed_issues") else APIHelper.SKIP
        pull_requests_merged = dictionary.get("pull_requests_merged") if dictionary.get("pull_requests_merged") else APIHelper.SKIP
        pull_request_contributors = dictionary.get("pull_request_contributors") if dictionary.get("pull_request_contributors") else APIHelper.SKIP
        code_additions_deletions_4_weeks = CodeAdditionsDeletions4Weeks1.from_dictionary(dictionary.get('code_additions_deletions_4_weeks')) if 'code_additions_deletions_4_weeks' in dictionary.keys() else APIHelper.SKIP
        commit_count_4_weeks = dictionary.get("commit_count_4_weeks") if dictionary.get("commit_count_4_weeks") else APIHelper.SKIP
        # Return an object of this model
        return cls(forks,
                   stars,
                   subscribers,
                   total_issues,
                   closed_issues,
                   pull_requests_merged,
                   pull_request_contributors,
                   code_additions_deletions_4_weeks,
                   commit_count_4_weeks)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'forks={(self.forks if hasattr(self, "forks") else None)!r}, '
                f'stars={(self.stars if hasattr(self, "stars") else None)!r}, '
                f'subscribers={(self.subscribers if hasattr(self, "subscribers") else None)!r}, '
                f'total_issues={(self.total_issues if hasattr(self, "total_issues") else None)!r}, '
                f'closed_issues={(self.closed_issues if hasattr(self, "closed_issues") else None)!r}, '
                f'pull_requests_merged={(self.pull_requests_merged if hasattr(self, "pull_requests_merged") else None)!r}, '
                f'pull_request_contributors={(self.pull_request_contributors if hasattr(self, "pull_request_contributors") else None)!r}, '
                f'code_additions_deletions_4_weeks={(self.code_additions_deletions_4_weeks if hasattr(self, "code_additions_deletions_4_weeks") else None)!r}, '
                f'commit_count_4_weeks={(self.commit_count_4_weeks if hasattr(self, "commit_count_4_weeks") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'forks={(self.forks if hasattr(self, "forks") else None)!s}, '
                f'stars={(self.stars if hasattr(self, "stars") else None)!s}, '
                f'subscribers={(self.subscribers if hasattr(self, "subscribers") else None)!s}, '
                f'total_issues={(self.total_issues if hasattr(self, "total_issues") else None)!s}, '
                f'closed_issues={(self.closed_issues if hasattr(self, "closed_issues") else None)!s}, '
                f'pull_requests_merged={(self.pull_requests_merged if hasattr(self, "pull_requests_merged") else None)!s}, '
                f'pull_request_contributors={(self.pull_request_contributors if hasattr(self, "pull_request_contributors") else None)!s}, '
                f'code_additions_deletions_4_weeks={(self.code_additions_deletions_4_weeks if hasattr(self, "code_additions_deletions_4_weeks") else None)!s}, '
                f'commit_count_4_weeks={(self.commit_count_4_weeks if hasattr(self, "commit_count_4_weeks") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.price_change_percentage_24_h import PriceChangePercentage24h


class Data(object):

    """Implementation of the 'Data' model.

    Attributes:
        price (float): coin price in usd
        price_btc (str): coin price in btc
        price_change_percentage_24_h (PriceChangePercentage24h): coin price
            change percentage in 24 hours
        market_cap (str): coin market cap in usd
        market_cap_btc (str): coin market cap in btc
        total_volume (str): coin total volume in usd
        total_volume_btc (str): coin total volume in btc
        sparkline (str): coin sparkline image url
        content (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "price": 'price',
        "price_btc": 'price_btc',
        "price_change_percentage_24_h": 'price_change_percentage_24h',
        "market_cap": 'market_cap',
        "market_cap_btc": 'market_cap_btc',
        "total_volume": 'total_volume',
        "total_volume_btc": 'total_volume_btc',
        "sparkline": 'sparkline',
        "content": 'content'
    }

    _optionals = [
        'price',
        'price_btc',
        'price_change_percentage_24_h',
        'market_cap',
        'market_cap_btc',
        'total_volume',
        'total_volume_btc',
        'sparkline',
        'content',
    ]

    def __init__(self,
                 price=APIHelper.SKIP,
                 price_btc=APIHelper.SKIP,
                 price_change_percentage_24_h=APIHelper.SKIP,
                 market_cap=APIHelper.SKIP,
                 market_cap_btc=APIHelper.SKIP,
                 total_volume=APIHelper.SKIP,
                 total_volume_btc=APIHelper.SKIP,
                 sparkline=APIHelper.SKIP,
                 content=APIHelper.SKIP):
        """Constructor for the Data class"""

        # Initialize members of the class
        if price is not APIHelper.SKIP:
            self.price = price 
        if price_btc is not APIHelper.SKIP:
            self.price_btc = price_btc 
        if price_change_percentage_24_h is not APIHelper.SKIP:
            self.price_change_percentage_24_h = price_change_percentage_24_h 
        if market_cap is not APIHelper.SKIP:
            self.market_cap = market_cap 
        if market_cap_btc is not APIHelper.SKIP:
            self.market_cap_btc = market_cap_btc 
        if total_volume is not APIHelper.SKIP:
            self.total_volume = total_volume 
        if total_volume_btc is not APIHelper.SKIP:
            self.total_volume_btc = total_volume_btc 
        if sparkline is not APIHelper.SKIP:
            self.sparkline = sparkline 
        if content is not APIHelper.SKIP:
            self.content = content 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        price = dictionary.get("price") if dictionary.get("price") else APIHelper.SKIP
        price_btc = dictionary.get("price_btc") if dictionary.get("price_btc") else APIHelper.SKIP
        price_change_percentage_24_h = PriceChangePercentage24h.from_dictionary(dictionary.get('price_change_percentage_24h')) if 'price_change_percentage_24h' in dictionary.keys() else APIHelper.SKIP
        market_cap = dictionary.get("market_cap") if dictionary.get("market_cap") else APIHelper.SKIP
        market_cap_btc = dictionary.get("market_cap_btc") if dictionary.get("market_cap_btc") else APIHelper.SKIP
        total_volume = dictionary.get("total_volume") if dictionary.get("total_volume") else APIHelper.SKIP
        total_volume_btc = dictionary.get("total_volume_btc") if dictionary.get("total_volume_btc") else APIHelper.SKIP
        sparkline = dictionary.get("sparkline") if dictionary.get("sparkline") else APIHelper.SKIP
        content = dictionary.get("content") if dictionary.get("content") else APIHelper.SKIP
        # Return an object of this model
        return cls(price,
                   price_btc,
                   price_change_percentage_24_h,
                   market_cap,
                   market_cap_btc,
                   total_volume,
                   total_volume_btc,
                   sparkline,
                   content)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'price={(self.price if hasattr(self, "price") else None)!r}, '
                f'price_btc={(self.price_btc if hasattr(self, "price_btc") else None)!r}, '
                f'price_change_percentage_24_h={(self.price_change_percentage_24_h if hasattr(self, "price_change_percentage_24_h") else None)!r}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!r}, '
                f'market_cap_btc={(self.market_cap_btc if hasattr(self, "market_cap_btc") else None)!r}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!r}, '
                f'total_volume_btc={(self.total_volume_btc if hasattr(self, "total_volume_btc") else None)!r}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!r}, '
                f'content={(self.content if hasattr(self, "content") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'price={(self.price if hasattr(self, "price") else None)!s}, '
                f'price_btc={(self.price_btc if hasattr(self, "price_btc") else None)!s}, '
                f'price_change_percentage_24_h={(self.price_change_percentage_24_h if hasattr(self, "price_change_percentage_24_h") else None)!s}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!s}, '
                f'market_cap_btc={(self.market_cap_btc if hasattr(self, "market_cap_btc") else None)!s}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!s}, '
                f'total_volume_btc={(self.total_volume_btc if hasattr(self, "total_volume_btc") else None)!s}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!s}, '
                f'content={(self.content if hasattr(self, "content") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.categories_list import CategoriesList
from coingeckopublicapiv3.models.categories import Categories


class CategoriesController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(CategoriesController, self).__init__(config)

    def coins_categories_list(self):
        """Does a GET request to /coins/categories/list.

        This endpoint allows you to **query all the coins categories on
        CoinGecko**

        Returns:
            CategoriesList: Response from the API. List all categories

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/categories/list')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CategoriesList.from_dictionary)
        ).execute()

    def coins_categories(self,
                         order=None):
        """Does a GET request to /coins/categories.

        This endpoint allows you to **query all the coins categories with
        market data (market cap, volume, ...) on CoinGecko**

        Args:
            order (Order2Enum, optional): sort results by field, default:
                market_cap_desc

        Returns:
            Categories: Response from the API. List all categories with market
                data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/categories')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('order')
                         .value(order))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Categories.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DaysEnum(object):

    """Implementation of the 'days' enum.

    Attributes:
        ENUM_1: The enum member of type str.
        ENUM_7: The enum member of type str.
        ENUM_14: The enum member of type str.
        ENUM_30: The enum member of type str.
        ENUM_90: The enum member of type str.
        ENUM_180: The enum member of type str.
        ENUM_365: The enum member of type str.

    """
    ENUM_1 = '1'

    ENUM_7 = '7'

    ENUM_14 = '14'

    ENUM_30 = '30'

    ENUM_90 = '90'

    ENUM_180 = '180'

    ENUM_365 = '365'

